@@ -5,17 +5,21 @@ Unstable experiments with NAFF.
 :license: MIT, see LICENSE for more details.
 """
 
-__version__ = "0.3.1"
+__version__ = "0.5.0"
 
 
 from .slash_commands import *
 from .slash_param import *
+from .speedup.install import install_naff_speedups
 
 __all__ = (
     "TansySlashCommandParameter",
     "TansySlashCommand",
+    "SlashCommand",
+    "tansy_slash_command",
     "slash_command",
     "ParamInfo",
     "Param",
     "Option",
+    "install_naff_speedups",
 )
